# displayPlot.py
#
from graphics import *
from sys  import maxsize

colors= ("green","purple","blue","orange","yellow","purple")
ncolors = len(colors)

win = GraphWin("Dijkstra's Shortest Paths",400,400)
drawn = []

fig = 0

def display_clear() :
    for obj in drawn : obj.undraw()

def display_frame (banner, nodes) :
    global fig
    display_clear()
    fig += 1
    banner = "Fig %d:  %s" % (fig,banner)
    txtBanner = Text(Point(200,20), banner)
    txtBanner.draw(win)
    drawn.append(txtBanner)

    display_edges(nodes)
    display_nodes(nodes)
    win.getMouse()

def display_edges(nodes) :
    edges = {}
    for node in nodes :
        for nbr,dist in node.nbrs :
            tag = tuple(sorted((node.pos,nbr.pos)))  # same edge seen twice
            state,dist = edges.get(tag, (0,dist)) # white line
            if nbr.prev == node : state = node.state
            edges[tag] = state, dist

    for tag in edges :
        start,end = tag      # split start/end positions
        state,dist = edges[tag]
        color = colors[state]
        p1 = Point(start[0], start[1])
        p2 = Point(end[0], end[1])
        line = Line(p1,p2)
        line.setFill(color)
        line.draw(win)
        drawn.append(line)

        mid = ((start[0]+end[0])/2, (start[1]+end[1])/2)
        txtDist = Text(Point(mid[0],mid[1]), str(dist))
        txtDist.draw(win)
        drawn.append(txtDist)

def display_nodes(nodes) :
    for node in nodes :
        color = colors[node.state]
        label = "%s--%d" % (node.name,node.srcDist)
        if node.srcDist == maxsize: label = "%s" % node.name
        x,y = node.pos
        txtNode = Text(Point(x,y), label)
        txtNode.setFill(color)
        txtNode.draw(win)
        drawn.append(txtNode)

def display_close() :
    win.close()
